//
//  NSDate+EWECategory.h
//  MDTPro
//
//  Created by William on 16/9/23.
//  Copyright © 2016年 EWell. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface NSDate (EWECategory)

/*!
 *  根据生日获取年龄精确到年
 *
 *  @param birth 生日
 *
 *  @return 年龄
 */
+ (NSString*)ageWithBirthday:(NSString*)birth;
/*!
 *  根据生日获取年龄精确到年
 *
 *  @param birthDay 生日
 *
 *  @return 年龄
 */
+ (NSString*)ageWithBirthdayDate:(NSDate*)birthDay;

/*!
 *  根据生日获取年龄精确到天 不足一天精确到小时
 *
 *  @param birth 生日
 *
 *  @return 年龄
 */
+ (NSString*)ageDetailWithBirthday:(NSString*)birth;
/*!
 *  根据生日获取年龄精确到天 不足一天精确到小时
 *
 *  @param birthDay 生日
 *
 *  @return 年龄
 */
+ (NSString*)ageDetailWithBirthdayDate:(NSDate*)birthDay;
/*!
 *  比较两个时间的月份
 *
 *  @param startDate
 *  @param enddate
 *
 *  @return
 */
+ (NSComparisonResult)compareMonthStartDate:(NSDate*)startDate endDate:(NSDate*)enddate;
/*!
 *  比较年龄
 *
 *  @param age 被比较年龄
 *
 *  @return
 */
- (NSComparisonResult)compareAge:(int)age;
/*!
 * 比较年龄
 *
 *  @param age       被比较年龄
 *  @param birthDate 生日
 *
 *  @return
 */
+ (NSComparisonResult)compareAge:(int)age birthDate:(NSDate*)birthDate;
/*!
 *  根据 NSTimeInterval 返回 xx小时xx分xx秒
 *
 *  @param timeInterval 时长
 *
 *  @return xx小时xx分xx秒
 */
+(NSString*)dateStrByNSTimeInterval:(NSTimeInterval)timeInterval;
/*!
 *  根据未来的时间确定时间段
 *
 *  @param futureDay 结束时间
 *
 *  @return 时间段 [xx年][xx月][xx天][xx小时][xx分钟]
 */
+ (NSString*)durationWithFutureDate:(NSDate*)futureDay;

/*!
 *  根据未来的日期获取年份
 *
 *  @param futureDay 日期
 *  @return 星期几
 */
+ (NSString*)yearWithDate:(NSDate*)futureDay;
/*!
 *  根据未来的日期获取那年的第几月
 *
 *  @param futureDay 日期
 *  @return 星期几
 */
+ (NSString*)monthWithDate:(NSDate*)futureDay;
/*!
 *  根据未来的日期获取那月的第几天
 *  @param futureDay 日期
 *  @return 星期几
 */
+ (NSString*)dayWithDate:(NSDate*)futureDay;
/*!
 *  根据未来的日期获取星期几
 *
 *  @param futureDay 日期
 *  @return 星期几
 */
+ (NSString*)weekDayWithDate:(NSDate*)futureDay;
/*!
 *  获取星期几
 *
 *  @return 星期几
 */
- (NSString*)weekDayStringzh_CN;

/*!
 *  根据格式获取当前日期
 *
 *  @param  formatter
 *  @return 规定格式的当前时间
 */
+ (NSString*)currentDateStrWithFormatter:(NSString*)formatter;

@end
