//
//  NSString+EWECategory.h
//  DoctorCloudPortal
//
//  Created by William on 16/9/8.
//  Copyright © 2016年 WX. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>

@interface NSString (EWECategory)

/*!
 *  用NSUTF8StringEncoding编码Url中的特殊字符
 *
 *  @param url 被编码url
 *
 *  @return 编码后的url
 */
+ (NSString *)ewell_URLEncode:(NSString *)url;

/*!
 *  将带中文字符的Url转为utf8格式的url
 *
 *  @param urlStr
 *
 *  @return
 */
+ (NSString *)utf8_UrlEncode:(NSString*)urlStr;


+ (NSString *)changeJsonStringToTrueJsonString:(NSString *)json;

/*!
 *  jsonString 转为Object-C 可识别类型
 *
 *  @param jsonString
 *
 *  @return NSString, 有序的NSDictionary or Array
 */
+ (id)orderDictionaryOrArrayWithJsonString:(NSString*)jsonString;

/*!
 *  jsonString 转为Object-C 可识别类型
 *
 *  @param jsonString
 *
 *  @return NSString,NSDictionary or Array
 */
+ (id)dictionaryOrArrayWithJsonString:(NSString*)jsonString;

/*!
 *  NSDictionary NSArray 转 jsonStr
 *
 *  @param data NSDictionary or NSArray
 *
 *  @return jsonString
 */
+ (NSString *)toJsonstring:(id)data;

/*!
 *  NSDictionary NSArray 转 jsonStr 转码url
 *
 *  @param data NSDictionary or NSArray
 *
 *  @ jsonString
  */
+ (NSString*)toJsonstringUrlEncoded:(id)data;
/*!
 *  NSDictionary NSArray 转 jsonStr 转码url
 *
 *  @param data NSDictionary or NSArray
 *
 *  @jsonString
 */
+ (NSString*)toJsonstringUrlDecoder:(id)data;

/*!
 *  判断字符串是不是jsonStr
 *
 *  @param string 要被判断的字符串
 *
 *  @return 是 YES, 否 NO
 */

+ (BOOL)isJsonString:(NSString*)string;

/*!
 *  正则表达式验证
 *
 *  @param string 被验证String
 *  @param regExp 正则表达式string
 *
 *  @return 通过 YES, 未通过 NO
 */

+ (BOOL)isValidateString:(NSString*)string regExp:(NSString*)regExp;

/*!
 *  判断String是不是htmlStr
 *
 *  @return 通过 YES, 未通过 NO
 */
+ (BOOL)isHtmlStr:(NSString*)str;

/*!
 *  htmlStr 转 attributedString
 *
 *  @param htmlString
 *
 *  @return
 */
+ (NSAttributedString *)AttributedStringFromHtmlString:(NSString*)htmlString;


/*!
 * 根据nsstring 生成加行间距的 attributedString
 *
 *  @param string
 *  @param lineSpacing 行间距
 *  @param font        字体
 *
 *  @return NSMutableAttributedString
 */
+ (NSMutableAttributedString*)attributedStrByStr:(NSString*)string lineSpacing:(NSInteger)lineSpacing font:(UIFont*)font;

/*!
 *  根据nsstring 或者 htmlString 生成加行间距的 attributedString
 *
 *  @param string string 或者 htmlString
 *  @param lineSpace 行间距
 *  @param textFont  字体
 *
 *  @return NSMutableAttributedString
 */
+ (NSAttributedString*)attributedStringByStringOrHtmlString:(NSString*)string lineSpace:(NSInteger)lineSpace font:(UIFont*)font;
/**
 *  拼音 -> pinyin
 */
- (NSString *)transformToPinyin;

/**
 *  拼音首字母 -> py
 */
- (NSString *)transformToPinyinFirstLetter;

/*!
 * 根据nsstring 生成加行间距的 attributedString
 *
 *  @param string
 *  @param lineSpacing 行间距
 *  @param font        字体
 *
 *  @return NSMutableAttributedString
 */
- (NSAttributedString*)attributedStrByLineSpacing:(NSInteger)lineSpacing font:(UIFont*)font;

@end
