//
//  EWEDefine.h
//  MDTPro
//
//  Created by William on 16/8/3.
//  Copyright © 2016年 EWell. All rights reserved.
//

#ifndef EWEDefine_h
#define EWEDefine_h

/*!
 *  根据 rgba 和alpha生成 UIColor
 *
 *  @param r red
 *  @param g green
 *  @param b blue
 *  @param a alpha
 *
 *  @return UIColor
 */
#define rgba(r,g,b,a)   [UIColor colorWithRed:(r/255.0) green:(g/255.0) blue:(b/255.0) alpha:a]
/*!
 *  根据 16进制颜色码 和 alpha值生成UIColor
 *
 *  @param colorRgb 16进制颜色码
 *  @param __a      alpha值
 *
 *  @return UIColor
 */
#define RGB(colorRgb,__a)  [UIColor colorWithRed:((colorRgb & 0xFF0000) >> 16)/255.0 green:((colorRgb & 0xFF00) >> 8)/255.0 blue:((colorRgb & 0xFF)/255.0) alpha:__a]

/*!
 *  根据 rgba 生成 alpha为 1 的 UIColor
 *
 *  @param r red
 *  @param g green
 *  @param b blue
 *  @param a alpha
 *
 *  @return UIColor
 */
#define RGBColor(r, g, b) [UIColor colorWithRed:(r)/255.0 green:(g)/255.0 blue:(b)/255.0 alpha:1]

/*!
 *  随机颜色
 *
 *  @return UIColor
 */
#define RandomColor RGBColor(arc4random_uniform(255), arc4random_uniform(255), arc4random_uniform(255))

#define SelectedBackGroudColor [UIColor colorWithRed:3/255.0 green:169/255.0 blue:244/255.0 alpha:1.0]

/*
 屏幕尺寸
 */

#define HEIGHT [UIScreen mainScreen].bounds.size.height
#define WIDTH [UIScreen mainScreen].bounds.size.width

#define SizeWithScaling(num) (num) * WIDTH/375

#pragma mark - 字体大小适配
#define CurrentFontSize(fontSize) iPhone6Plus_6sPlus ? fontSize * 1.1f : iPhone6_6s ? fontSize : fontSize * 0.853f


#pragma mark - 判断当前的iPhone设备/系统版本

//判断是否为iPhone
#define IS_IPHONE (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPhone)
//判断是否为iPad
#define IS_IPAD (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad)
//判断是否为ipod
#define IS_IPOD ([[[UIDevice currentDevice] model] isEqualToString:@"iPod touch"])
// 判断是否为 iPhone 5SE
#define iPhone5SE [[UIScreen mainScreen] bounds].size.width == 320.0f && [[UIScreen mainScreen] bounds].size.height == 568.0f
// 判断是否为iPhone 6/6s
#define iPhone6_6s [[UIScreen mainScreen] bounds].size.width == 375.0f && [[UIScreen mainScreen] bounds].size.height == 667.0f
// 判断是否为iPhone 6Plus/6sPlus
#define iPhone6Plus_6sPlus [[UIScreen mainScreen] bounds].size.width == 414.0f && [[UIScreen mainScreen] bounds].size.height == 736.0f
//获取系统版本
#define IOS_SYSTEM_VERSION [[[UIDevice currentDevice] systemVersion] floatValue]
//判断 iOS 8 或更高的系统版本
#define IOS_VERSION_8_OR_LATER (([[[UIDevice currentDevice] systemVersion] floatValue] >=8.0)? (YES):(NO))
//判断 iOS 10 或更高的系统版本
#define IOS_VERSION_10_OR_LATER (([[[UIDevice currentDevice] systemVersion] floatValue] >=10.0)? (YES):(NO))


//校验性正则表达式
/**
 *  身份证校验
 */
#define regExp_IdCard @"^[1-9]\\d{5}[1-9]\\d{3}((0\\d)|(1[0-2]))(([0|1|2]\\d)|3[0-1])\\d{3}([0-9]|X|x)$"
/**
 *  email校验
 */
#define regExp_Email @"[A-Z0-9a-z._%+-]+@[A-Za-z0-9.-]+\\.[A-Za-z]{2,4}"
/**
 *  手机号校验
 */
#define regExp_Phone @"^((13[0-9])|(15[^4,\\D])|(18[0,0-9]))\\d{8}$"

/**
 *  固话号码校验
 */

#define regExp_Telphone @"/^\\d{3}-\\d{8}|\\d{4}-\\d{7}|\\d{4}-\\d{8}$/"

/**
 *  匹配由数字组成的字符串
 */
#define regExp_Number @"^[0-9]+$"
/**
 *  匹配由26个英文字母的大写组成的字符串
 */
#define regExp_Capital @"^[A-Z]+$"
/**
 *  匹配由26个英文字母的小写组成的字符串
 */
#define regExp_Samll @"^[a-z]+$"
/**
 *  匹配由数字和26个英文字母的大写组成的字符串
 */
#define regExp_CapAndNum @"^[A-Z0-9]+$"
/**
 *  匹配由数字和26个英文字母的小写写组成的字符串
 */
#define regExp_SamlAndNum @"^[a-z0-9]+$"
/**
 *  匹配由26个英文字母组成的字符串
 */
#define regExp_CapAndSaml @"^[A-Za-z]+$"
/**
 *  匹配由数字和26个英文字母组成的字符串
 */
#define regExp_CapSamlNum @"^[A-Za-z0-9]+$"
/**
 *  匹配由数字、26个英文字母或者下划线组成的字符串
 */
#define regExp_CapSamlNumUnderLine @"^\w+$"
/**
 *  匹配由键盘上所有可见字符组成的字符串
 */
#define regExp_AllKeyboard

//字符串长度限制
/**
 *  手机号最大长度
 */
#define limit_PhoneMax 11
/**
 *  验证码长度
 */
#define limit_VerifyCodeMax 6
/**
 *  登录密码最大长度
 */
#define limit_PasswordMax 14
/**
 *  二次密码最大长度
 */
#define limit_CheckPadMax 4
/**
 *  身份证最大长度
 */
#define limit_IdCardMax 18
/**
 *  评论字符长度限制
 */
#define limit_EvaluateMax 180
/**
 *  固话号码最大长度
 */
#define limit_TelphoneMax 13
/**
 *  医保卡号最大长度
 */
#define limit_YBCardMax 30


#endif /* EWEDefine_h */
